package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`MP`!````,"5```````!``````````*BC````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````)R:````````G)H`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````B`0`````
M``#P%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#`G0```````,"=00``````P)U!``````!``@``````
M`$`"`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`&)'-FWC,\0:ZRUMVFA/;'>E`8OYA````!0```!`````*````H!``*`)&
M$0```&``5@)0&(((!"!(`!$1``@0`@`@`````````$@"(`X`"P``A`*H00@%
M(&@(Q$DX0A25!D$H"BA8B($%8`26"`E"2G!``!@!`4!""`!`@(S`!``($)`0
M`P$`"($8@(%`0(*9@"Q`"`(!!"``8``)!)$CA(J75&`%``````````8````'
M````"0`````````````````````````*````#`````X````0````$0```!(`
M```4````%P`````````9```````````````:````'0```!X`````````(@``
M`",````D`````````"4````F````*@`````````L```````````````M````
M+@```"\````P`````````#0````U`````````#D``````````````#H````]
M````/@`````````_````0````$(```!$````1P````````!*````2P```$P`
M``!-`````````$X```````````````````````````````````!/````4```
M``````!2`````````%0```!6````6`````````````````````````!9````
M70````````!?`````````&$`````````8P```&0``````````````&8```!G
M````:0```&H```!M````7Y:3'*-:[Y#"CH?_5]N3'`TZEPO2402$@72"#7KP
M2FM]08[%=E0\E,T_#*_W(\X@B0=PTR!TL`+59-1\9J_,9BY./?;;]P!>!J2'
M_P&O-.BQ2)WGSMY'+>"G`@K/2J[_XT?&`3Y^EGS&#N`][#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75['SM$0]0[A'CA_F<@5J:.P^[E9,<04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\+LWI,<2B)]_PN*$%>M2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;W9OXW"]T$M]GB+'J&L)0]8A8F0'?JF<FV+0^H+L
M+/:+:W^:?-"?+/R'\)9\[@M1^?/;TQV0=8(-0V9+$`5LLLT\K3D-%^I:\:/@
M^TGB5\085Y):4OW2[P]NQ=\??)`0Z2W?_D@NQ9NVWJO*G\G5LG$`````````
M```````````````````````1````(``````````````````````````M````
M(``````````````````````````\````(`````````````````````````!0
M````(`````````````````````````"$`P``$@```#`A0```````````````
M``!'`@``$@```#`@0`````````````````#"`@``$@```)`?0```````````
M``````#>`@``$@```(`B0`````````````````!Y!```(``7`"BB00``````
M``````````#-`0``$@```.`A0`````````````````"[`@``$@```$`B0```
M``````````````"]`0``$@```#`?0``````````````````%!0``$@`-`*A8
M0```````0`````````#B`P``$``8`$BB00````````````````!U`@``$@``
M`.`?0`````````````````"@`@``$@```+`B0`````````````````"Y!```
M$0`7`$"B00``````"``````````A`P``$@```.`>0``````````````````A
M!0``$@`-`#!40```````_`,```````!>!```$@`-`%Q%0```````-`$`````
M``"+`P``$@```/`?0`````````````````"&`@``$@```(`@0```````````
M```````R`P``$@`````?0`````````````````#Q`P``$``8`+"R00``````
M```````````/`0``$@```"`A0`````````````````!J!```$@`-`&1*0```
M````S`D```````"3!```$@`-`%1"0```````\``````````\!```$@```$`A
M0`````````````````!1!```$@`-`#Q%0```````(`````````!P`@``$@``
M`-`>0`````````````````"M`@``$@```'`@0`````````````````"6`0``
M$@```'`A0``````````````````.`P``$@```(`A0`````````````````">
M`P``(0`8`&BB00``````"``````````O`@``$@```%`B0```````````````
M```V`@``$@```*`B0`````````````````#0`@``$@```+`>0```````````
M``````#/`P``$``7`$BB00````````````````"U`@``$@```-`@0```````
M``````````#K`@``$@```!`A0`````````````````">````$@```"`B0```
M```````````````I`@``$@```*`@0`````````````````!6`P``$@`````B
M0`````````````````!/`@``$@```#`B0`````````````````"?`P``(0`8
M`&BB00``````"`````````#\`P``$``8`+"R00`````````````````K`P``
M$0`8`$BB00``````"``````````)!```$@`-`'190```````!`````````"A
M`0``$@```,`?0`````````````````!O`0``$@```+`@0```````````````
M``"I!```$@`-`/Q80```````>`````````#E!```$@`-`"!)0```````1`$`
M```````3!```$@`.`'A90`````````````````"/`@``$@```)`@0```````
M``````````!]!```$@`-`#`E0`````````````````#2!```$@`+`$@>0```
M``````````````"^````$@```&`A0`````````````````#)`@``$@```*`>
M0````````````````````P``$@```+`?0``````````````````"`0``$0`8
M`%BB00```````0````````"$!```$0`/`(A90```````!`````````#6`P``
M$``8`$BB00````````````````!=`P``$@```,`A0`````````````````!U
M`P``$@```)`>0`````````````````!J````$@```+`A0```````````````
M```<`0``$@```/`A0`````````````````#0!```$@`-`-!!0```````-```
M```````X`0``$@```'`?0``````````````````$!```$``8`+"R00``````
M``````````#8!```$@`-`$A#0```````]`$```````#3````$@```"`?0```
M``````````````!>`@``$@```$`?0`````````````````"'````$@```)`B
M0``````````````````5`@``$@```&`@0`````````````````"O`0``$@``
M`!`B0`````````````````#A````$@```!`@0`````````````````#S````
M$@```&`B0``````````````````M`0``$0`8`%"B00``````!`````````"=
M`P``$0`8`&BB00``````"`````````!A`0``$@```-`?0```````````````
M``#7`@``$@`````@0`````````````````#P`P``$``8`+"R00``````````
M``````#W!```$@`-`&1(0```````E``````````9`P``$@```!`?0```````
M``````````"O````$@```&`?0`````````````````!G`P``$@```,`>0```
M``````````````!W!```$``7`"BB00````````````````"]`P``$0`8`&"B
M00``````"``````````J!```$@`-`/A(0```````*`````````#K`0``$@``
M`"`@0`````````````````#8`0``$@```%`@0`````````````````"8`P``
M$@`-`-`B0```````5`(```````!"`P``$@`````A0``````````````````]
M`0``$@```*`A0``````````````````Y`P``$@```/`>0```````````````
M``#V`0``$0`8`'"B00``````$P````````#Y`@``$@```(`>0```````````
M``````#E`@``$@```%`A0`````````````````!]`@``$@```%`?0```````
M``````````#D`0``$@```*`?0`````````````````!]`P``$@```.`@0```
M``````````````##!```$@`-`)!&0```````U`$```````!)`P``$@```(`?
M0`````````````````!"`0``$@```-`A0`````````````````"G`@``$@``
M`,`B0`````````````````!%!```$@`-`"Q80```````?`````````!X````
M$@```/`@0`````````````````!_`0``$@```'`B0``````````````````9
M!```$@`-`$1#0```````!`````````"(`0``$@```$`@0```````````````
M``!.`0``$@```)`A0```````````````````;&EB<&5R;"YS;RXU+C(P`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?
M4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`
M;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N
M-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A
M8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K
M7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?
M7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C
M=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS
M7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?
M8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!'3$E"0U\R+C$W```````````````"``,``@`"``$````"
M`````0`!``(``@`!``(``0`!``(``@`"``$````!``$``@`!``(``@````(`
M`@`#``,``@`!``(``@````,``@`#``(``0`"``$```````$``0`!``(``0`!
M`````@`"`````0`!``(``@```````0````$``0````(````#````````````
M`@````(``0`!``(````"``$`!``!```````!``(``@`"`````@`"``(``@`"
M``$``@````(``0```````0```````````````0`!`*<#```0````(````)>1
ME@8```0`-P4````````!``$`!0(``!`````@````EY&6!@```P`W!0``````
M``$``0!4`@``$`````````"7D98&```"`#<%````````X)]!```````!!```
M`@``````````````2*)!````````!```+P``````````````4*)!````````
M!```3@``````````````6*)!````````!```/```````````````8*)!````
M````!```6```````````````:*)!````````!```3P``````````````<*)!
M````````!```8````````````````*!!```````"!```80``````````````
M"*!!```````"!```0```````````````$*!!```````"!```.@``````````
M````&*!!```````"!```)0``````````````(*!!```````"!```5@``````
M````````**!!```````"!```'@``````````````,*!!```````"!```$@``
M````````````.*!!```````"!```7P``````````````0*!!```````"!```
M%P``````````````2*!!```````"!```5```````````````4*!!```````"
M!```1P``````````````6*!!```````"!```#```````````````8*!!````
M```"!```2```````````````:*!!```````"!```8P``````````````<*!!
M```````"!```50``````````````>*!!```````"!```1```````````````
M@*!!```````"!```9P``````````````B*!!```````"!```!P``````````
M````D*!!```````"!```9```````````````F*!!```````"!```.P``````
M````````H*!!```````"!```,0``````````````J*!!```````"!```4```
M````````````L*!!```````"!```#P``````````````N*!!```````"!```
M%0``````````````P*!!```````"!```40``````````````R*!!```````"
M!```3```````````````T*!!```````"!```6@``````````````V*!!````
M```"!```!@``````````````X*!!```````"!```;@``````````````Z*!!
M```````"!```6P``````````````\*!!```````"!```2@``````````````
M^*!!```````"!```'P```````````````*%!```````"!```%@``````````
M````"*%!```````"!```-@``````````````$*%!```````"!```*@``````
M````````&*%!```````"!```,@``````````````(*%!```````"!````@``
M````````````**%!```````"!```)P``````````````,*%!```````"!```
M90``````````````.*%!```````"!```:P``````````````0*%!```````"
M!```70``````````````2*%!```````"!```*```````````````4*%!````
M```"!```&0``````````````6*%!```````"!```!0``````````````8*%!
M```````"!```'```````````````:*%!```````"!```8@``````````````
M<*%!```````"!```.0``````````````>*%!```````"!```(```````````
M````@*%!```````"!```(0``````````````B*%!```````"!```;P``````
M````````D*%!```````"!```7@``````````````F*%!```````"!```00``
M````````````H*%!```````"!```/P``````````````J*%!```````"!```
M:```````````````L*%!```````"!```"@``````````````N*%!```````"
M!```0@``````````````P*%!```````"!```*P``````````````R*%!````
M```"!```2P``````````````T*%!```````"!```*0``````````````V*%!
M```````"!```+```````````````X*%!```````"!```"P``````````````
MZ*%!```````"!```(P``````````````\*%!```````"!```30``````````
M````^*%!```````"!```;````````````````*)!```````"!```"```````
M````````"*)!```````"!```20``````````````$*)!```````"!```)```
M````````````&*)!```````"!```$```````````````(*)!```````"!```
M:0``````````````_7N_J?T#`)'*`0"4_7O!J,`#7]8`````\'N_J=```)`1
M_D?Y$.(_D2`"']8?(`/5'R`#U1\@`]70``"P$0)`^1`"`)$@`A_6T```L!$&
M0/D0(@"1(`(?UM```+`1"D#Y$$(`D2`"'];0``"P$0Y`^1!B`)$@`A_6T```
ML!$20/D0@@"1(`(?UM```+`1%D#Y$*(`D2`"'];0``"P$1I`^1#"`)$@`A_6
MT```L!$>0/D0X@"1(`(?UM```+`1(D#Y$`(!D2`"'];0``"P$29`^1`B`9$@
M`A_6T```L!$J0/D00@&1(`(?UM```+`1+D#Y$&(!D2`"'];0``"P$3)`^1""
M`9$@`A_6T```L!$V0/D0H@&1(`(?UM```+`1.D#Y$,(!D2`"'];0``"P$3Y`
M^1#B`9$@`A_6T```L!%"0/D0`@*1(`(?UM```+`11D#Y$"("D2`"'];0``"P
M$4I`^1!"`I$@`A_6T```L!%.0/D08@*1(`(?UM```+`14D#Y$(("D2`"'];0
M``"P$59`^1"B`I$@`A_6T```L!%:0/D0P@*1(`(?UM```+`17D#Y$.("D2`"
M'];0``"0$6)`^1`"`Y$@`A_6T```D!%F0/D0(@.1(`(?UM```)`1:D#Y$$(#
MD2`"'];0``"0$6Y`^1!B`Y$@`A_6T```D!%R0/D0@@.1(`(?UM```)`1=D#Y
M$*(#D2`"'];0``"0$7I`^1#"`Y$@`A_6T```D!%^0/D0X@.1(`(?UM```)`1
M@D#Y$`($D2`"'];0``"0$89`^1`B!)$@`A_6T```D!&*0/D00@21(`(?UM``
M`)`1CD#Y$&($D2`"'];0``"0$9)`^1""!)$@`A_6T```D!&60/D0H@21(`(?
MUM```)`1FD#Y$,($D2`"'];0``"0$9Y`^1#B!)$@`A_6T```D!&B0/D0`@61
M(`(?UM```)`1ID#Y$"(%D2`"'];0``"0$:I`^1!"!9$@`A_6T```D!&N0/D0
M8@61(`(?UM```)`1LD#Y$((%D2`"'];0``"0$;9`^1"B!9$@`A_6T```D!&Z
M0/D0P@61(`(?UM```)`1OD#Y$.(%D2`"'];0``"0$<)`^1`"!I$@`A_6T```
MD!'&0/D0(@:1(`(?UM```)`1RD#Y$$(&D2`"'];0``"0$<Y`^1!B!I$@`A_6
MT```D!'20/D0@@:1(`(?UM```)`1UD#Y$*(&D2`"'];0``"0$=I`^1#"!I$@
M`A_6T```D!'>0/D0X@:1(`(?UM```)`1XD#Y$`('D2`"'];0``"0$>9`^1`B
M!Y$@`A_6T```D!'J0/D00@>1(`(?UM```)`1[D#Y$&('D2`"'];0``"0$?)`
M^1""!Y$@`A_6T```D!'V0/D0H@>1(`(?UM```)`1^D#Y$,('D2`"'];0``"0
M$?Y`^1#B!Y$@`A_6T```D!$"0?D0`@B1(`(?UM```)`1!D'Y$"((D2`"'];0
M``"0$0I!^1!"")$@`A_6T```D!$.0?D08@B1(`(?UM```)`1$D'Y$(((D2`"
M'];]>[JI_0,`D?-3`:GU6P*IU```D*!/`+F#@@F1H2,`^:`S`9&B'P#YH0,!
MD:+C`)%D`$#YI"\`^00`@-+3``"0>/__EP(``)````"00D`&D0"`")'A`P*J
M<`T`E,```)``8$DY0`$`-3K__Y?"``"P0%0!^<`.`+33``"0!?__EV!20KE#
M__^7'U0B.6!20KE`__^7X@,`JF!20KE!R%(Y(0`?,D'($CDZ__^7`LA2.:%/
M0+GA`V>>0@``,B$4`!$"R!(Y(7Q`DR``8YX`*&$>00P`7!`@81[L"0!4(/!]
MT],``+`G__^7Y@,`JJ0C0/G"``"08"(.D:=/0+F!`$#Y_P0`<<$``/D!``#P
M(<`WD<$$`/D!``#P0B!!^2'@-Y$&`!'XP0P`^8$`@%+""`#Y`8`0N*T!`%3A
M"`!1@B``D2`(`)'C`("2H0"`4H`,`(M%A$#X9,PAB\5H)/@A!``17P``ZV'_
M_U1V(@Z1`0``T.(,`!$$`(#2XP,&JB$0")'``E+XYQ``$<?,)XO_@!_X8/__
ME_4#`"K@`@`T=B(.D<`"4OC3_O^7````\*%3`9$`("V1=`4`E&`"`+1S(@Z1
ME(()D6`"4OBV_O^71?__EZ(O0/F!`D#Y00`!RN`#%2I!`P"U\U-!J?5;0JG]
M>\:HP`-?UL`"4OAJ__^7]0,`*N?__Q?`@E'X``$`M-0,`)3K__\7P0``D```
M`/`AP`F1`*`WD1O__Y<```#PH5,!D0!`*Y%4!0"4P((1^`#\_[3'#`"4WO__
M%][^_Y<@`(!2;/[_EQ\@`]4```````#`0QT`@-(>`(#2_0,`D>4#`*KA`T#Y
MXB,`D>8#`)&@``!8PP``6.0``%BF_O^7W?[_E]`B0```````_%A```````!T
M64```````*```/``\$?Y0```M,_^_Q?``U_6`````,$``)#```"0(2`)D0`@
M"9$A'`"1(0``RS\X`/&)``!4@0``6$$``+0@`!_6P`-?U@``````````P```
MD,$``)``(`F1(2`)D2$``,LB_$.30OQ"BT'\09.!``"TH@``6$(``+1``!_6
MP`-?UA\@`]4``````````/U[OJG]`P"1\PL`^=,``)!@#DHY@```-=S__Y<@
M`(!28`X*.?,+0/G]>\*HP`-?UOU[OZF@``#P_0,`D0!`-Y$!`$#Y80``M?U[
MP:C=__\7@0``6*'__[0@`#_6^___%P``````````_T,*T<L``)!A@0F1"N``
MD0S@`9']>[^I_0,`D:9C`)$B`$#YHD\!^0(`@-)!A4#XQD``D23<>-,B_&#3
M*1QHTR7\2-.$''"22-QXTZ4<>)*$``FJ(_QHTX0`!:I"'&C3!1UPDF,<>)*B
M``*J)WQ8TT(``ZJ$``>J0>!!JE\!#.O$`!_XP8`?^"']_U2A8P"1HP,"D2:@
M"9%E@%WX8R``D7\`!NMA@%_X9`!:^&(`6?BA``'*(0`$RB$``LHB``&+07Q!
MJB%\0))A"`#Y8?[_5`4$0/DB,X_2!`!`^4)0J_(&"$#YJH1BTP<,0/E*"46J
M"!!`^8GH>].L#T#Y2GU`DN,`)8K!``6*#`$,B\T`)(IA``&J@@$"BR-M1*I,
M`02*B81BTXT!#:I#0".+K!-`^6,``8LI"42JH1=`^6)\0)(I?4"2+S./TBXS
MC])0`2**3U"K\DY0J_+!``&+8P`)BNP`#(LA``Z+C`$/BP,"`ZJ,`0V+(P`#
MBTZ$8M.A&T#Y+3./TD_H>]/."4*J35"K\BT`#8O.?4"2XFU"JH)!(HM!?$"2
M0@`.BBP!(8JJ`0J+@@$"JC"$8M.M'T#Y0@$"BRSH>],0"D&J*C./TA!^0)*!
M;4&J2E"K\F%`(8LC?$"2S`$CBJH!"HLA`!"*2@$)BX$!`:IIZ'O3;(1BTZ\C
M0/DI;4.J+3./TH,)0ZI"0"F+;'Q`DDE\0))-4*OR0@`,BNT!#8L/`BF*(^E[
MTZX!#HM!`0&+X@$"JBJ%8M//`0*+,3./TF)L2:JN)T#Y20E)JBI]0)(A0"*+
M45"K\B-\0)+1`1&+(0`*BHX!(XIMZ'O3,`(0BVF$8M/!`0&JLEM`^0X"`8NA
M;4.J(PE#JC`SC])I?$"2HRM`^>U!(8M04*ORHGU`DG``$(M!Z'O30X1BTT\!
M(HHA;$*JK0$)BF((0JI#?$"2[0$-JJ(O0/D,`@R+SD$ABR\SC]+!?4"2C`$-
MBS"$8M,MZ'O33U"K\C$!(8I/``^+HFU!J@$*0:J-02*+,#./TBQ\0)*A,T#Y
MHGU`DLX!`XI04*OR+@(.JC``$(NM`0R*Z@$*BV\`(HI*`0Z+[P$-JD[H>],)
M`@F+P6U"JBD!#XLO,X_23D$ABT]0J_+!?4"22H1BT[`W0/DMZ'O30@E"JI$!
M(8I*?$"2$`(/BZ)M0:HO02*+*81BT\X!"HHA"4&J`P(#BRE\0)(P,X_2H3M`
M^>)]0)(N`@ZJ4%"K\E$!(HHP`!"+3>A[TV,`#HOO`0F*K6U"JB\"#ZIN0"V+
M#`(,B\-]0))AZ'O3381BTXP!#XLA;$.JH@E"JH]!(8LP,X_2K#]`^4U\0))0
M4*OR,0$CBI`!$(O.`0V*X7U`DBX"#JILA&+3"@(*BR+H>]-*`0Z+@PE#JFQ\
M0))";$&JHT-`^4Y!(HLJ,X_2PGU`DDI0J_*Q`2&*8P`*B^\!#(I0Z'O3+P(/
MJBJ$8M-I``F+*0$/BT$)0:HJ?$"2`VY"JJ%'0/DP02.+*3./T@-^0)))4*OR
MD0$BBB$`"8O.`0J*;^A[TRX"#JHM``V+281BTZT!#HOA;4.JL4M`^:]!(8LB
M"4*J+3./TDE\0))-4*ORX7U`DD(!(XHM`@V+$`()BB[H>]-0`!"JK`$,BW&$
M8M.,`1"+PFU!JK!/0/F.02*+(PI#JBPSC]+"?4"28WQ`DDQ0J_(Q`2&*#`(,
MBTWH>]/O`0.*K6U"JB\"#ZHPA&+3B@$*BP$*0:I*`0^+L%-`^4I!+8LM,X_2
M(7Q`DDU0J_)Q`"**#0(-B\X!`8I0A&+3+@(.JJD!"8M/?4"2*0$.BP(*0JHN
M,X_2L%=`^>SI>]-.4*ORC&U/J@X"#HM"?$"2*4$LB_"%8M,L?4"2PP$#BRXS
MC](Q`"^*C>E[TP\*3ZI*`0**3E"K\BH""JJM;4RJ\7U`DDX"#HN2A6+34``L
MBF,`"HM,"DRJ8T`MB[)?0/EM?$"2*0$1BL$!`8LN=)W2JNE[TPD"":HNVZWR
MCP$/RDX"#HLA``F+26U-JB%`*8LJ?$"2XP$#2DGI>].PA6+3P@$"BQ`*3:I"
M``.+K6-`^2-M2JHI=)W2*=NM\D^%8M/J"4JJ0D`CBZT!"8M#?$"2"0(,RD\!
M$,INZ'O3(0$!2JT!$8OB`0)*K0$!BZ]G0/G!;4.J<H1BTZU!(8LN=)W2J7U`
MDE(*0ZHAZ7O3+MNM\NX!#HLA;$FJ3P(*RLQ!+(OC`0U*C`$"BRV%8M.,02&+
MKVM`^8%]0)(N=)W2K0E)JB+H>],NVZWRJ0$2RD)L0:KO`0Z+[T$PB^\!`XOO
M02*+XWU`DBP!#$IBZ'O3,81BTZEO0/DP=)W2,0I!JD)L0ZHPVZWR+G2=TBD!
M$(LI02J+*0$,BRP"#<HI02*+(GU`DH\!#TI!Z'O3<(1BTZQS0/D0"D.J(6Q"
MJB[;K?(*`A'*C`$.BXQ!,HN,`0^+C$$ABX%]0)))`0E*(^A[TT^$8M.J=T#Y
M+G2=TN\)0JIC;$&J+MNM\C)TG=)*`0Z+[@$0RDI!+8M*`0F+2D$CBT-]0)+,
M`0Q*8NA[TRV$8M.N>T#Y*72=TJT)0:I";$.J*=NM\LX!"8NI`0_*SD$QB\X!
M#(O.02*+PGU`DD'H>],J`0I*<81BTZE_0/DL=)W2,0I#JB%L0JHLVZWR+`$,
MBRD"#<J003"+"@(*BTI!(8M!?4"2+@$.2B/H>]-0A&+3J8-`^1`*0JIC;$&J
M,MNM\@P"$<HI`1*+*4$OBRD!#HLI02.+(WU`DHH!"DIBZ'O3+X1BTZR'0/DN
M=)W2[PE!JD)L0ZHNVZWR:X$)D8P!#HNNBT#YC$$MB^T!$,J,`0J+*G2=THQ!
M(HN"?4"20>A[TZD!"4HJVZWR;81BTZT)0ZK*`0J+(6Q"JE%!,8NJ`0_**0()
MBRE!(8LA?4"2(^A[TTP!#$I1A&+3JH]`^2YTG=(Q"D*J8VQ!JB[;K?).`0Z+
M*@(-RM!!,(L,`@R+C$$CBX-]0)))`0E*8NA[TS"$8M.JDT#Y+G2=TA`*0:I"
M;$.J+MNM\DH!#HL.`A'*2D$OBTH!"8M*02*+0GU`DLP!#$I!Z'O3;X1BTZZ7
M0/DI=)W2[PE#JB%L0JHIVZWRXP$0RLX!"8O.02V+S@$,B\Y!(8O!?4"2*>A[
MTVH`"DI-A&+3HYM`^2QTG=*M"4*J*6U!JBS;K?)L``R+D4$QBRH""HM*02F+
MJ0$/RC%TG=(N`0Y*J9]`^2R$8M,QVZWR*0$1BRE!,(LI`0Z+C@E!JLP!#<I#
M?4"2,'2=THH!"DJLHT#Y<81BTS#;K?)BZ'O3C`$0BXQ!+XN,`0J+*@I#JD)L
M0ZI#`0[**4$BBS!TG=(B?4"2:0`)2J.G0/E1A&+30>A[TS#;K?(A;$*J8P`0
MBV-`+8MC``F+*0I"JHQ!(8LQ`0K*@7U`DB_H>],L`@Q*,'2=TK&K0/GO;4&J
M+81BTV]`+XLPVZWRXWU`DJT)0:IBZ'O3,`(0BPY"+HO,`0R+3FQ#JHY!+HNL
M`0FJL`$)BN\!#(J1FY?2[P$0*K"O0/G"?4"2;(1BTW'CL?*,"4.J$0(1BT'H
M>],J0BJ+2@$/BR%L0JI/02&+B@$-JI`!#8K.`0J*D9N7TLX!$"JPLT#YX7U`
MDDJ$8M-QX['R2@E"JA$"$8LCZ'O3*4(IBRD!#HMC;$&J+D$CBTD!#*I0`0R*
M[P$)BI&;E]+O`1`JL+=`^<-]0)(IA&+3<>.Q\BD)0:H1`A&+8NA[TRU"+8NM
M`0^+0FQ#JJ]!(HLM`0JJ,`$*BLX!#8J1FY?2S@$0*K"[0/GB?4"2;81BTW'C
ML?*M"4.J$0(1BT'H>],L0BR+C`$.BR%L0JJ.02&+K`$)JK`!"8KO`0R*D9N7
MTN\!$"JPOT#YP7U`DDR$8M-QX['RC`E"JA$"$8LCZ'O3*D(JBTH!#XMC;$&J
M3T$CBXH!#:J0`0V*S@$*BI&;E]+.`1`JL,-`^>-]0)(JA&+3<>.Q\DH)0:H1
M`A&+8NA[TRE"*8LI`0Z+0FQ#JBY!(HM)`0RJ4`$,BN\!"8J1FY?2[P$0*K#'
M0/G"?4"2:81BTW'CL?(I"4.J$0(1BT'H>],M0BV+K0$/BR%L0JJO02&++0$*
MJC`!"HK.`0V*D9N7TLX!$"JPRT#YX7U`DDV$8M-QX['RK0E"JA$"$8LCZ'O3
M+$(LBXP!#HMC;$&JCD$CBZP!":JP`0F*[P$,BI&;E]+O`1`JL,]`^<-]0)(L
MA&+3<>.Q\HP)0:H1`A&+8NA[TRI"*HM*`0^+0FQ#JD]!(HN*`0VJD`$-BLX!
M"HJ1FY?2S@$0*K#30/GB?4"2:H1BTW'CL?)*"4.J$0(1BT'H>],I0BF+*0$.
MBR%L0JHN02&+20$,JE`!#(KO`0F*D9N7TN\!$"JPUT#YP7U`DDF$8M-QX['R
M*0E"JA$"$8LCZ'O3+4(MBZT!#XMC;$&JKT$CBRT!"JHP`0J*S@$-BI&;E]+.
M`1`JL-M`^>-]0)(MA&+3<>.Q\JT)0:H1`A&+8NA[TRQ"+(N,`0Z+0FQ#JHY!
M(HNL`0FJL`$)BN\!#(J1FY?2[P$0*K#?0/G"?4"2;(1BTW'CL?*,"4.J$0(1
MBT'H>],J0BJ+2@$/BR%L0JI/02&+B@$-JI`!#8K.`0J*D9N7TLX!$"JPXT#Y
MX7U`DDJ$8M-QX['R2@E"JA$"$8LCZ'O3*4(IBRD!#HMC;$&J+D$CBTD!#*I0
M`0R*[P$)BI&;E]+O`1`JL.=`^<-]0)(IA&+3<>.Q\BD)0:H1`A&+8NA[TRU"
M+8NM`0^+0FQ#JJ]!(HLM`0JJD)N7TLX!#8HM`0J*S@$-*JWK0/GB?4"2<81B
MTW#CL?(C"D.JL`$0BT'H>],,0BR+C`$.BR%L0JJ.02&+;``)JE&$8M/O`0R*
M;``)BN\!#"J0FY?2K.]`^2(*0JIPX['RP7U`DI`!$(L*0BJ+2@$/BT\``ZK.
M`0^*3P`#BLX!#RHMZ'O3K_-`^3&$8M.0FY?2K6U!JG#CL?(A"D&J\`$0BR\`
M`JI*02V+37U`DDH!#XHO``**3P$/*JSI>].J]T#Y"4(IBY";E]*,;4VJL85B
MTRD!#HMPX['R*4$LBRY]0))0`1"+S.E[TRH*3:H#0B.+8P`/BXQM3JIO0"R+
M0P$!JNQ]0)(I`0.*0P$!BB,!`RJ1FY?2J?M`^8WI>]/0A6+3<>.Q\A`*3JHQ
M`1&+(D(BBT(``XNI;4RJ#@(*RDU`*8NQ_T#YPCJ8TJE]0)+.`0]*0DRY\H^%
M8M,B`@*+[PE,JB/I>]-!0"&+(0`.B[$#0?GL`1#*8VQ)JBY`(XO!.IC2C0$-
M2D%,N?(LA6+3PWU`DB$"`8LJ0"J+2@$-BXT)2:IBZ'O3K`$/RD)L0ZJ.`0Y*
M<81BT\DZF-*L!T'Y,0I#JDI!(HM)3+GR0GU`DD'H>].,`0F+*0(-RB%L0JHJ
M`0I*C$$PBZD+0?F,`0Z+4(1BT\XZF-(0"D*JC$$ABTY,N?*!?4"2(^A[TRD!
M#HLI02^+*0$*BPH"$<IC;$&J3`$,2B^$8M/..IC2J@]!^>\)0:HI02.+3DRY
M\B-]0))BZ'O32@$.B^X!$,I";$.JR0$)2DI!+8NN$T'Y2@$,BVV$8M/,.IC2
MK0E#JDI!(HM,3+GR0GU`DD'H>]/.`0R+K`$/RB%L0JK.03&+B@$*2LX!"8M1
MA&+3K!=!^<DZF-(Q"D*JSD$ABTE,N?+!?4"2B0$)BR/H>],L`@W*,$$PBV-L
M0:J.`0Y*"@(*BZP;0?G0.IC2*81BTTI!(XM03+GR0WU`DHP!$(MBZ'O3C$$O
MBXP!#HLN"4&JR0$1RD)L0ZHJ`0I*C$$BBW"$8M."?4"2SSJ8TJD?0?D0"D.J
M0>A[TT],N?(A;$*J*0$/BRE!+8L-`@[**0$*BZP!#$HI02&+K2-!^2%]0)+*
M.IC2(^A[TT^$8M-*3+GR[PE"JJH!"HMC;$&J44$QB^H!$,HL`@R+C$$CBX-]
M0))BZ'O320$)2C*$8M.J)T'YS3J8TE(*0:I";$.J34RY\DT!#8M*`@_*KD$N
MB\D!"8LI02*+(GU`DDP!#$I!Z'O3<81BT\TZF-*J*T'Y,0I#JB%L0JI-3+GR
M2@$-BRT"$LI*03"+4(1BTTH!#(M*02&+07U`DA`*0JJI`0E*(^A[T\XZF-*M
M+T'Y`@(1RF-L0:I.3+GR2@`*2JT!#HNB,T'YK4$OB\PZF-*M`0F++X1BTZU!
M(XNC?4"2[PE!JFGH>]-,3+GR[@$0RDP`#(LI;4.JDD$RB\PZF-)*`@J+2D$I
MB\D!#4I"?4"2;81BTZXW0?FM"4.J0>A[TTQ,N?(A;$*JS@$,BZP!#\J#`0I*
MSD$QBTJ$8M/.`0F+T3J8TLY!(8NL.T'YP7U`DDH)0JHIZ'O344RY\D(!#<HI
M;4&JC`$1BXQ!,(N,`0.+C$$IBY!]0)).``Y*`^I[TRF$8M/1.IC2HC]!^2D)
M0:IC;%"J44RY\D(`$8M"0"^+0@`.BT)`(XLC`0K*3GQ`DFP`#$K!Z7O3SSJ8
MTA&&8M.C0T'Y(6Q.JC`*4*I/3+GR8P`/BV-`+8MC``R+8T`ABP$""<K-.IC2
M(@`"2J%'0?EL?$"234RY\H_I>],A``V+S85BTR%`*HNN"4ZJ(@`"B^%M3*K*
M.IC2(0`""\(!$,I#``-*HDM!^4I,N?(MZ'O30@`*BT)`*8M#``.+HFU!JD(`
M`PN/A6+31``$"P0``/DA``4+[`E,JH8!!@O.`0<+$`(("P$$`/D&"`#YHD]!
M^6$!0/E!``'*#@P`^1`0`/F!``"U_7O!J/]#"I'``U_6D/G_E_U[O*G]`P"1
M]5L"J?=C`ZGS4P&I]@,`JO@#`:J``P"TH```\!<T0?DW`P"TP`)`.1_T`'&`
M`P!48`,`-/0#%JJ`'D`X'_0`<4```%2@__\UE`(62_,"0/FS`0"TE'Y`D_4#
M%ZK@`Q.JX@,4JN$#%JI'^?^7@```-6!J=#@?]`!Q8`$`5+..0/CS_O^U``"`
MTO-30:GU6T*I]V-#J?U[Q*C``U_6%`"`4NO__Q>U`A?+@`8`D:'^0Y,!`P"Y
M8`(`B_-30:GU6T*I]V-#J?U[Q*C``U_6_7N\J?T#`)'S4P&I]1,`^;4``/#S
M`P"JH(()D0$`0/FA'P#Y`0"`TK0``/"ATP"1X`,3JK[__Y?@`0"TI#=`N8,V
M0?EAS"2+(@1`^6+8)/CB_O^T(2``D2($0/DB``#YHO__M:'3`)'@`Q.JL/__
MEV#^_[6U@@F1H1]`^:`"0/D@``#*H```M?-30:GU$T#Y_7O$J,`#7]8T^?^7
M_7NYJ?T#`)'S4P&I\P,!JOLK`/GU6P*I]V,#J?EK!*GV`P"JM0``\&`"0#FA
M@@F1(@!`^:(W`/D"`(#2'_0`<7,6DYK@`Q.JJ?C_E_<#`*JADP&1X`,6JH[_
M_Y?T`P"JH`<`M*+X_Y<?0#?K@@8`5+1G0+FX``#PP`)`.1_T`'$@"P!4``L`
M-.(#%JH"```4@0``-$$<0#@_]`!QH?__5$(`%DL9-T'YX`H`$0```@O+^/^7
M(%LT^``*`+0`-T'YP08`D:-G0+G"`D`Y`%AC^`(``#FB```U!@``%"(40#@"
M'``X8@``-%_T`'&!__]4H@>`4@$$`)$"```Y8!9`."`4`#C`__\U``"`4K6"
M"9&B-T#YH0)`^4$``<HA!P"U\U-!J?5;0JGW8T.I^6M$J?LK0/G]>\>HP`-?
MU@$`@-)B:F$X@FHA."$$`)&B__\U[O__%[@``/`;-T'Y8`-`^6`$`+3B`QNJ
M%`"`4D.,0/B4!@`1P___M8`*`!$`?'V3H0``\"*(0KEB`0`TX0,`JN`#&ZK&
M^/^7`#<!^>`"`+2:?D"36@<`D1]X.OBT9P"YLO__%R(`@%(BB`*YB/C_E_D#
M`*J@`0"TFGY`D^$#&ZI"\WW3/OC_EQDW`?G@`QFJ\?__%P(`@%*O__\7``*`
MTA0`@%+C__\7``"`$L3__Q>S^/^7_7NSJ?T#`)'S4P&I]5L"J?=C`ZFT``#P
M]0,`JH&""9$B`$#YHF<`^0(`@-)@``"T`0!`.6$!`#64@@F1H6=`^8`"0/D@
M``#*@`@`M?-30:GU6T*I]V-#J?U[S:C``U_6.OC_E_8#`*J`_O^T&```T!B#
M*9'@`Q:JX/C_E^4#`*K@!`"TH4Q`.3^X`'$@!0!4X`,5JK-,`)$4^/^7]P,`
MJN`#$ZH1^/^7```7"P`(`!$`?$"32?C_E_<#`*KE`Q.JY`,5JN,#&*H"`("2
M(0"`4@KX_Y>B(P&1X0,7J@``@%(.^/^7'P0`,:```%2@6T"Y``P4$A\00'&@
M`@!4X`,7JOKX_Y?@`Q>JM/C_E^`#%JJZ^/^7Y0,`JF#[_[7@`Q:J9OC_E^`#
M%:J8^/^7P___%Z!00#D`^O\T'[@`<:'Z_U2@5$`Y@/G_--+__Q?@`Q>JK/__
ME^S__Q=<^/^7_7N]J?T#`)'S4P&ILP``\/43`/E@4D*Y2?C_EP%P0/E@4D*Y
M-01`^47X_Y<!M$(Y8%)"N308`!)!^/^7``1`^0!`0'D`(!E3@`(`*J`&`'E@
M4D*Y.OC_EP%P0/E@4D*Y-`1`^3;X_Y<!``#0`@"`TB&`-Y%B^/^7@!8`^6!2
M0KDO^/^7`7!`^6!20KDT!$#Y*_C_EP%$0_E@4D*Y@1H`^2?X_Y<!<$#Y8%)"
MN30$0/DC^/^7`,!`^8`#`+1@4D*Y'_C_EP#`0/D!5$#Y8%)"N8$>`/D:^/^7
M`7!`^6!20KDA!$#Y/R``^17X_Y<!<$#Y8%)"N2$$0/D_$`#Y$/C_EP%P0/E@
M4D*Y,P1`^0SX_Y<`C$'Y8"8`^?-30:GU$T#Y_7O#J,`#7]8!`(#2Z/__%_U[
MOJG]`P"1\U,!J;,``-#T`P"J8%)"N?WW_Y<"8`:1X0,4J@``@%)!^/^7H```
M-```@%+S4T&I_7O"J,`#7]9@4D*Y\O?_EP"H0;D`#!02'Q!`<>```%1@4D*Y
M[/?_EP"H0;D`#!02'RA`<2'^_U1!`(!2X`,4J@7X_Y<?`!]KX!>?&O-30:G]
M>\*HP`-?UO\'0-'B_X'2_X,`T?U[O:G]`P"1]5L"J?-3`:FS``#0]0,`JF."
M"9$```"P]@,!J@"@*9&A(P&19`!`^:0G"/D$`(#2<O?_EQ\`'VL-!`!4`P0`
M4:$C`9%T?$"3(6AT.$$#`#04?$"3H",!D>(#%*KA!8!2H!\`^3GX_Y>``@"T
MH```T`!00KF]]_^7HA]`^>,#%*KA`Q6J.?C_EW.""9&A)TCY8`)`^2```,K@
M`0"U\U-!J?5;0JG]>\.H_X,`D?\'0)'``U_6`_W_-:```-``4$*YJO?_E^(#
M%JKA`Q6J@_?_E^[__Q>Q]_^7H```T/U[OZG]`P"1`%!"N:#W_Y<#``"PXO__
ML`$``+!C0":1_7O!J$+`/)$AX"F1W/?_%_U[OJG]`P"1\PL`^;,``-!@4D*Y
MDO?_E^W__Y=@4D*YC_?_E_,+0/D$``"P`@``L(2`-Y$!``"P_7O"J`4`@%+C
M`P2J0L`0D2%@*I'H]_\7_PM`T?_#`-']>[VI_0,`D?43`/FU``#0\U,!J:""
M"9$!`$#YH2\0^0$`@-)$]_^7Y`,`*J$C`9&A'P#Y!0``L`,``+"@'T#YI<`J
MD6/@*I$B`(+2(0"`4@7W_Y=`!/@WH4,`D0`*@M(```&+`@""T@!``-&@&P#Y
MH!]`^:$;0/D']_^7\P,`JO,"^#=@!@`1`'Q`DR[W_Y?T`P"J0`(`M'-^0).A
M&T#YX@,3JN#V_Y>?:C,XX`,4JK6""9&B+U#YH0)`^4$``<HA`0"U\U-!J?43
M0/G]>\.H_\,`D?\+0)'``U_6``"`TO3__Q=4]_^7Q/__%_\'0-'_0P#1_7NZ
MJ?T#`)'S4P&I]5L"J?=C`ZGY:P2I^RL`^;8``-#T`P"JPH()D0```+#S`P&J
M`$`KD:&3`9%#`$#YHS<(^0,`@-*P_?^7]0,`JN$%@%+@`Q2JE_?_EX`"`+0`
M``"PX0,4J@"`*Y$#_O^7X`,4JM:""9&B-TCYP0)`^4$``<I!"P"U\U-!J?5;
M0JGW8T.I^6M$J?LK0/G]>\:H_T,`D?\'0)'``U_6X`,4JA@``+"L]O^7^P,`
M*@'#*Y'@`Q.JI/;_E_,#`*J@_/^T%P``L!H``+`9``"P]R(KD5KC*Y$Y`RR1
M80)`.3\`'VMS$I>:M0``M.$#$ZK@`Q6J.??_ER`%`#3@`Q.JEO;_E^(#`*I@
MPB"+`/!?.!^\`'$!`0!40@0`441\0)-G`@2+?VHD..3P7SB?O`!Q0/__5&$'
M`!$B``(+7_P_<:SX_U0"`(+2(0"`4N0#$ZKF`Q2JY0,:JN,#&:J@HP&1LP``
MT('V_Y=@4D*YY_;_EP)@!I&AHP&1``"`4H/V_Y?@```U8%)"N>#V_Y<`J$&Y
M``P4$A\@0''@``!4`<,KD0``@-)I]O^7\P,`JH#Y_[6I__\7(0"`4J"C`9'S
M]O^7X/[_-0```+"AHP&1`(`KD:?]_Y>@HP&1B/;_EZ/__Q?6]O^7`0!`.<$`
M`#0"!`"1/[P`<0`0@II!%$`XH?__-<`#7];]>[ZI_0,`D?-3`:GS`P"J8`,`
MM!0`0#DT`P`T3O;_EP`$`-%B`@"+?P("ZV(!`%1@:F`X'[P`<:```%0>```4
M0`!`.1^\`'%A`P!40@0`T5\`$^MA__]4?P("Z^$#`%2?O@!QP```5/-30:D`
M``"P_7O"J`#@*Y%?]O\70`"`TG'V_Y?A`P"JX`0`M`(``+!"("N10@!`>2(`
M`'GS4T&I_7O"J,`#7]9``$`Y'[P`<4`!`%1"!`#1?P("ZV/__U1_`@+KH0``
M5.;__Q=``$`Y'[P`<8$``%1"!`#1?P("ZV/__U1"`!/+0`@`D1\$0/&H`0!4
MH```T.$#$ZH`(`J1`P""TA0@`)%"!`"1X`,4JE'V_Y?@`Q2J\U-!J?U[PJC`
M`U_6``"`TO-30:G]>\*HP`-?UOU[N*D!``"P````L"%`)I']`P"1`"`LD?-3
M`:GU6P*I]QL`^;,``-`F'$&I)!1"J6.""9$A8$!Y8@!`^:(_`/D"`(#2H>,`
M>:8?!:FD%P:I$OW_EQ4``+````"P%@``L`!@+)$7``"P%```L`O]_Y>4HBV1
M````L`"`+)$'_?^7````L`#`+)$$_?^7H.(LD0+]_Y<```"P`"`MD?_\_Y?`
M0BN1_?S_E^!B+9'[_/^7X`,4JOG\_Y<```"P`.`MD?;\_Y<```"P`(`KD?/\
M_Y<```"P`"`ND?#\_Y<```"P`&`ND>W\_Y<```"PH3,!D0"@+I&T_/^7@```
MM.$#`*K@`Q2J#/W_EP```+"A,P&1```OD:S\_Y>@``"TX0,`J@```+``8"^1
M`_W_EP```+"A,P&1`*`OD:/\_Y=``@"TX0,`JL!"*Y'[_/^7`0``L*#B+)$A
M@#"1<X()D?;\_Y>A/T#Y8`)`^2```,H@`P"U\U-!J?5;0JGW&T#Y_7O(J,`#
M7]8```"PH3,!D0#@+Y&-_/^7H```M.$#`*K@8BV1Y?S_E^K__Q<!``"P0@&`
MTB%`,)&@AP&1YO7_EX#\_S6AKP&1X&(MD=O\_Y?@__\7#/;_E_U[O:G]`P"1
M\U,!J;0``-"S``#08(()D0$`0/FA%P#Y`0"`TH`Z0KD?!``Q(`$`5'.""9&B
M%T#Y80)`^4$``<J!`@"U\U-!J?U[PZC``U_6````L*&3`)$`8"V19?S_ER`!
M`+0!`$`Y/P`?:^('GQH_P`!QX`>?&D````J`.@*Y[/__%P``@%*`.@*YZ?__
M%^?U_Y?]>[^I_0,`D8#U_Y</]O^7@```M```0/G]>\&HP`-?U@``@-+]__\7
M_7NVJ0(``+#]`P"10D`FD4+@`)'S4P&I]5L"J?=C`ZGY:P2IMP``T/8#`*KA
M@@F10`!`^2,`0/FC3P#Y`P"`TD$80/E&'$&I1!1"J4,$0/GS`P"JH#,`^:,W
M`/FF'P>II!<(J:%+`/G@`@"T!0``L`,``+"UHP&1N<`KD7@`+)$%```4-_;_
MET`#`+2SAD#XLP$`M*%S`9'@`Q.J)OS_E_0#`*KA`Q:J8```M`(`0#FB_O\U
MX`,3JGO\_Y>SAD#XL_[_M?>""9&A3T#YX`)`^2```,I@`P"U\U-!J?5;0JGW
M8T.I^6M$J?U[RJC``U_6X`,6JB?U_Y?Z`P"JX`,4JB3U_Y=``P"+``@`D5WU
M_Y?Z`P"JY@,4JN4#&:KD`Q:JXP,8J@(`@)(A`(!2'?7_E^$#&JK@`Q.J6_S_
ME^#__Q>,]?^7_R-`T0P``+#_0P71C$$FD8$A`I&.X0*1$#.0TOU[N:G]`P"1
MZ"<&;?-3`:GU6P*I]V,#J?EK!*G[<P6IL8,`D;0``-"*+4>IK:,"D8]!0/DH
M)$"I)AQ!J2040JG"#4"IC&5`^8Z""9$0`A&+%0``L/]#`-'W`P"JH3,"D:!"
M*Y'1`4#Y$0(`^1$`@-*O4P#YJB\)J:P)`/FH)PRIIA\-J:07#JFB#0"ITOO_
ME_,#`*I@``"T`0!`.4$@`#5V__^7]@,`JF`@`+3@`Q:JX/3_EP```(L`!`"1
M&?7_EQD``+#$`D`Y^`,`JO,#`*HYPS"1)`$`-.`#$ZKC`QFJ`@"`DB$`@%)S
M"@"1U?3_E\0>0#@D__\UH&-`^;8C`Y&```"U#P``%,"&0/B@`0"TH3,"D;#[
M_Y?S`P"J8/__M`$`0#DA__\T*_W_E^#^_S3@`Q.JY_3_E^0#`*H@`P"ULTM`
M^?,*`+1@`D`Y-@"`4J`!`#53```4H8,`D0`TD-(```&+`<PVBR$@0-$AP`31
M,P!`^7,)`+1@`D`YU@8`$0`)`#3@`Q.J$_W_EV#^_S3@`Q.JS_3_E^0#`*K@
M_?^TX`,$JJ0_`/D:``"PH?3_E_,#`*K@`QBJGO3_EP``$PL3$!`1<WY`D^`#
M$ZK5]/^7]@,`JJ0_0/D&``"P`P``L.<#&*K&X#"11>,KD6,`,9$"`("2(0"`
M4I+T_Y<!.(!2X`,6JH_U_Y<?!``QX`0`5+@``-``4T*Y\O3_EP)@!I'A`Q:J
M``"`4C;U_Y>@!0`TH```T.,"0/D"``"PY`,6JD)@,Y$A`(!2`"1!^1'U_Y<`
M`(#2HH,`D0$SD-*4@@F1(0`"BR(`0/F!`D#Y00`!RN$Y`+6_`P"1Z"=&;?-3
M0:GU6T*I]V-#J?EK1*G[<T6I_7O'J/]#!9'_(T"1P`-?U@0`@-*___\77O7_
MEP4`0+F_1`!QX/K_5*```-#C`D#Y`@``L.0#%JI"0#&1(0"`4@`D0?GO]/^7
M``"`TM[__Q<`4T*YO_3_EP"H0;D`#!02'Q!`<>'Y_U0`4T*YN?3_EQFP0;E?
M]/^7/P,`:R'Y_U0`4T*YL_3_EP"H0;D`(``2'P`'<6'X_U3@`Q.J??3_E_,#
M`*H```"PH3,"D0"`.9$E^_^7`#,`M/@"0/EA]/^7X0,`JN`#&*I<_?^7^`,`
MJB`R`+3@`QBJ,O3_EQ\,`''Y`P"J[0$`5`!\0),!``"P`!``T2%`,I$``P"+
MR?3_EP`!`#4_$P!Q8"@`5#D3`%$9PSF+(/-?.!^\`''`)P!4C?[_E\```#4!
M`(!2X`,8J@3U_Y?[`P`J(`H`-0$``+````"P(8`PD0!@+9%:XRN1&```L%C[
M_Y<7`(!22?3_E^8#`"H'``"P`P``L.>`-Y'E`QJJY`,6JF/`,I$"`("2(0"`
M4N`#$ZKY`P>J^P,:JA@#,Y$']/^7$0``%/WT_Y<``$"Y'T0`<4$"`%0U]/^7
M]P8`$>8#`"KY`P#YYP,7*N4#&ZKD`Q:JXP,8J@(`@)(A`(!2X`,3JO;S_Y<!
M.(!2X`,3JO/T_Y<?!``Q@/W_5.`#%JJG]/^7X0,3JJ!"*Y$M^_^7X`,3JH+^
M_Y?@`Q.J;?__%W_^_Y?@`Q.J"?3_EVG__Q>@`P>1$P"`TKBC`I$9T`318&IX
M^*`!`+3A`QFJP?K_EV```+0"`$`Y8@``-7,B`)'X__\7^O/_E_8#`*K@W?^U
M<R(`D?/__Q<6``"PH`&`TM:B,)'M_O\70@"`4B$"@)(G]/^7P@"`TJ'C!I'@
M`QLJH_3_EZ#C1CF````UH.=&.1\,`7%@'P!4N<,#D0(`@%(CXP"1`0"`TN`#
M&RII`&>>%_3_E[^/`/DD8(32(W&5TL*?F]+!CHK2`#Z<TJ3HK/*C^;WR0A>S
M\D$&HO)`>KCRI'L`^:-_`/FB@P#YH8<`^:"+`/F_DP#YOVL!N0(`D-*AXP:1
MX`,;*H'T_Y<?`!]K_`,`JO<#`"H-"0!4HH]`^8!_0).CDT#Y00P`BR%\0))?
M``'K20``5&,$`)&B:T&Y8'1`BZ&/`/F@DP#Y8A4`-`$(@%(@PR*+-P`"2P#@
M`)&?`Q=KH>,&D9?3EQKX?D"3X@,8JGKS_Y>@:T&YX`(`"Z!K`;D?``%QH?O_
M5*'C!I'@`QFJEP,72SP`&(ML]?^7__X`<:T4`%3W`@%1^'X&4P@#)QX8!P"1
MF!L8BXHO0*F()T&IAA]"J9P#`9&DHP21X`,9JH(/?ZF*+`"IB"0!J88<`JF"
M#`.I6?7_EY\#&.MA_O]4``$F'N$'@!(77`$;XGY`DP,)@-+A`QBJ(`%FGI/S
M_Y>W:P&Y`@"0TJ'C!I'@`QLJ.O3_EQ\`'VO\`P"J]P,`*DSW_U3@`QLJT//_
ME[B/0/F@`P>1XP^`$@$C0],"P"&+(`0`$4.`%C@?X`!QMY-`^>P.`%2B`P>1
M0,`@B^(&@%(`8`+10@`!2P$`@%)"?$"3EO/_E^'^6-/E_E#3XOY(TP3_6-,#
M_U#3H,,#D:&#!3D!_TC3MX\%.1D``)"XGP4YMR,&D:6'!3FXQP61HHL%.?NB
M`)&DDP4Y.<,PD:.7!3FAFP4Y'?7_EZ5[0/FC?T#YHH-`^:;\4-.AAT#YJOQ(
MTZ"+0/EI_%C3:/Q0TV?\2-.D?%C3I<\%.:;'!3E%_%#31OQ8TZK+!3FITP4Y
M2OQ(TZC7!3DI_%C3I]L%.2C\4-.CWP4Y)_Q(TZ;C!3D#_$C3!OQ8TZ7G!3FD
MPP4Y!?Q0TZKK!3FB[P4YJ?,%.:CW!3FG^P4YH?\%.:8#!CFE!P8YHPL&.:`/
M!CD"```4!!=`..`#%ZKC`QFJ`@"`DB$`@%+W"@"1`?/_E_\"&^L!__]4!P``
MD`,``)#G@#>1IB,&D47C*Y'D`Q:J8X`RD0(`@)(A`(!2X`,3JK_#!CGS\O^7
MX`,6JJGS_Y?A`Q.JH$(KD2_Z_Y?@`Q.JA/W_E^`#$ZIO_O\7O.,&D6G__Q?W
M!D#Y5]C_M.`#%ZK@\O^7'PP`\<G7_U0`$`#1`0``D"%@,I'@`@"+>?/_EQ\`
M'VL8$Y>:MO[_%_@#'*IQ__\7X@>`4D(``4NAPP.1(,`@BP$`@%)"?$"3`.``
MD2#S_Y>@PP.1NO3_E[^O`/F@HP21'WP`J1]\`:D??`*I@___%Z#K1CD?!`%Q
M@>#_5*#O1CD?#`%Q(>#_5*#S1CD?(`%QP=__5*#W1CD?%`%Q8=__5$(`@%(A
M!X"2X`,;*A3S_Y>AXP:1(@6`TN`#&RJ0\_^7!P``D`,``)#G@#>1IN,&D47C
M*Y'D`Q:J8X`RD0(`@)(A`(!2X`,3JJGR_Y>X_O\7^`)`^6_^_Q<9\_^7_7NX
MJ?T#`)'Y:P2IN@``L/LK`/GS4P&I]5L"J?=C`ZF[``"P8(,)D0$`0/FA/P#Y
M`0"`TD!30KG^\O^7(@"`4@*D`CD```"0H=,!D0#@+)%U^?^7@```M`$`0#D_
MQ`!Q0!$`5'_\_Y=`4T*YM@``T/#R_Y<!``"08P&`4B(`@%(AP#21__+_E\`&
M`+0!"$#YP"(.D0"`4+@Y%$#Y'P0`<0T&`%05`(!2,P"`4EA#"9$+```4@0A`
M^>`#%ZH1\_^78`0`-<`B#I%S!@`1M08`$0"`4+@?`!-K[0,`5``#0+G4\O^7
M`P"`4J)^0)/A`QFJ///_E_0#`*J@`@"T!`!`^<,B#I$"@(!2`@2@<H$,0+E@
M`%'X(@`""E\`$'$7V'/XH/S_5``#0+G"\O^7@0)`^4,`@%("`(#2JO+_E^$#
M`*K@`Q>J[_+_E^#[_S3`(@Z1`(!0N`$$`%$_`!5KP`D`5$!30KFT``"PLO+_
MEP$``)!C`(!2(@"`4B'@-)'!\O^7\P,`JH`!`+2`4D*YJ?+_EV$*0/D"``"0
M0@`UD2$`0/F`\O^78`I`^0``0/D`#$"Y0!"P-T!30KFT``"PG?+_EP$``)!C
M`(!2(@"`4B$@-9&L\O^7\P,`JL`!`+0```"0H=,!D0"`*Y$/^?^7X@,`JJ`W
M`/F`4D*YP@H`M(WR_Y=A"D#YHC=`^2$`0/EE\O^70%-"N=4B#I&&\O^7'Z0"
M.0```)"ATP&1`$`KD?[X_Y>@@A'X]`,`JJ`$`+0!.(!2%//_EP$$`!$_!`!Q
M:0``5!]$`'%A#`!4>X,)D:$_0/E@`T#Y(```RJ`+`+7S4T&I]5M"J?=C0ZGY
M:T2I^RM`^?U[R*C``U_6``1`.>#N_S1U__\7'P0`<4WV_U0S`(!25$,)D8`"
M0+ES!@`18?+_E^$#&:H/\O^7P"(.D0"`4+@?`!-K#/__5*;__Q>@`E'XV?S_
MEZ""$?C`!P"T80I`^0"`@%(`!*!R(0!`^2(,0+E````*'P`0<>$$`%0@"$#Y
MUB(.D=0"4?CA`Q2J<?+_E_4#`"I@"D#Y`H"`4@($H'*4`D#Y!`!`^8`,0+D"
M``(*7P`0<>$!`%2""$#Y````D.,#%2KA`Q2J`.`UD7GR_Y<X\O^7P"(.D6(*
M0/D!`%'X0`!`^2$`0/E3^O^7J?__%T!30KDO\O^780I`^0(`@-)#`(!2(0!`
M^1;R_Y?B`P"JZ___%Z```+``4$*Y)?+_EV$*0/E#`(!2`@"`TB$`0/D,\O^7
MT___%X!20KD=\O^780I`^2$`0/EV\O^7>O__%P```)``0#615O+_ER'R_Y>A
M`E'XXP,`*@```)#B`Q2J`(`VD2$`0/E.\O^7_7N^J?T#`)'S4P&I]`,`JDC[
M_Y<!`$`Y\P,`JL$``#0"!`"1/[P`<7,2@II!%$`XH?__-0'\_Y=``0`T-`$`
MM(`"0#G@```T`0``D.`#$ZHAX#"1@/+_EW\"`.N```!4\U-!J?U[PJC``U_6
MX`,4JO-30:G]>\*H2?G_%_U[OJG]`P"1\PL`^;,``+!@4D*YZ?'_EP$`@!+?
M\?^78%)"N>7Q_Y?S"T#YX?__T`(`@-+]>\*H(9`\D6OR_Q>D``"P@\`(D4,`
M`+2#&$'YDO'_%_U[O*G]`P"1\U,!J?=C`ZFT``"0N```D!@#-Y&4(C>1E`(8
MRY3^0Y/U6P*I]P,`*O8#`:KU`P*J$P"`TD3Q_Y<T`0"T`WMS^.`#%RKA`Q:J
MX@,5JF``/]9S!@"1?P(4ZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UL`#7];]
M>[^I_0,`D?U[P:C``U_6`0`"``````!P97)L>'-I+F,`````````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````$!>0```````4%Y`
M``````!87D```````&!>0```````:%Y```````"`7D``````````````````
M.%Y```````#(6D``````````````````V%M````````87D```````"!>0```
M````*%Y````````P7D```````````````````%Y````````(7D``````````
M````````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4`
M`````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0``````````!0
M05)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$523#5,
M24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````
M4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?05)'0P``````
M````4$%27T%21U9?,````````%!!4E]'3$]"04Q?1$5"54<``````````%!!
M4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,14%./0``
M`````#$`````````4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,`
M`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H```````!P87)L`````"YP87(`````)7,E
M<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S
M```````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````05)'5@`````8`````````'!E<FP`````,`````````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&5X96-U=&EO
M;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``````````"5S````````+64````````M+0```````%5315(`````55-%
M4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````
M+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`
M````1%E,1%],24)205)97U!!5$@`````````4TA,24)?4$%42````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I
M('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["G-E96L@
M7T9(+"`M."P@,CL*<F5A9"!?1D@L("1B=68L(#@["FQA<W0@=6YL97-S("1B
M=68@97$@(EQN4$%2+G!M7&XB.PIS965K(%]&2"P@+3$R+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL
M96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H
M;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D
M97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U
M="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP
M<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME
M>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S
M("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U
M<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U
M9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[
M8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@
M)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@
M)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D
M;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE
M;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD
M<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6
M>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI
M9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L
M971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2
M.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]
M"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F
M:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P
M*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`]('-O<G0@>PIL96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"GT@
M9W)E<"!["B$O0E-$4$%.+PI](&=R97`@>PHH)&)U;F1L92!N92`G<VET92<I
M(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@
M)69I;&5S.PHO7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK
M(&9O<B!K97ES("4Z.CL*)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W
M<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M
M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*
M;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN
M*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL
M92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%
M*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A
M<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I
M;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H
M*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE
M7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D
M0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H
M<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M
M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F
M:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H
M*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C
M*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A
M<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI
M;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@
M)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E
M>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N
M=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T
M=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6
M>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3
M*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#@F0```````""9```````````````````$`
M`````````0`````````!``````````4"`````````0````````!4`@``````
M``$`````````IP,````````,`````````$@>0```````#0````````!X64``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````&`"0```````!0``````
M``"@$$````````8`````````(`9````````*`````````$(%````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@````````!X!@```````!0`````````!P`````````7`````````-`70```
M````!P`````````H%T````````@`````````J``````````)`````````!@`
M````````_O__;P````#(%D```````/___V\``````P````````#P__]O````
M`.(50```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`
M``````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````
M8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```
M````8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>
M0```````8!Y```````!@'D```````&`>0```````8!Y```````!@'D``````
M`&`>0```````8!Y```````!@'D```````&`>0```````8!Y```````!@'D``
M`````&`>0```````8!Y```````!@'D```````&`>0```````8!Y```````!@
M'D```````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`````
M``!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`
M``````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````
M8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```
M````8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>
M0```````8!Y```````!@'D````````````````````````````#_____````
M`)!>0```````1T-#.B`H56)U;G1U+TQI;F%R;R`T+CDN,2TQ-G5B=6YT=34I
M(#0N.2XQ`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XX+C,M,3%U8G5N='4Q*2`T
M+C@N,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG
M;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`
M+F)S<P`N8V]M;65N=``!```````,`(`>0```````````````````)'@`````
M````````````````````````````````````````````````````````````
M```````````````````````````+`````0````(```````````)`````````
M`@```````!L````````````````````!````````````````````$P````<`
M```"`````````!P"0```````'`(````````@````````````````````!```
M`````````````````"$````'`````@`````````\`D```````#P"````````
M)`````````````````````0````````````````````T````]O__;P(`````
M````8`)```````!@`@```````,`#````````!0`````````(````````````
M````````/@````L````"`````````"`&0```````(`8```````"`"@``````
M``8````!````"``````````8`````````$8````#`````@````````"@$$``
M`````*`0````````0@4```````````````````$```````````````````!.
M````____;P(`````````XA5```````#B%0```````.``````````!0``````
M```"``````````(`````````6P```/[__V\"`````````,@60```````R!8`
M``````!@``````````8````#````"````````````````````&H````$````
M`@`````````H%T```````"@7````````J``````````%``````````@`````
M````&`````````!T````!````$(`````````T!=```````#0%P```````'@&
M````````!0````P````(`````````!@`````````?@````$````&````````
M`$@>0```````2!X````````4````````````````````!```````````````
M`````'D````!````!@````````!@'D```````&`>````````<`0`````````
M`````````!``````````$`````````"$`````0````8`````````T")`````
M``#0(@```````*@V```````````````````(````````````````````B@``
M``$````&`````````'A90```````>%D````````0````````````````````
M!````````````````````)`````!`````@````````"(64```````(A9````
M````$$$```````````````````@```````````````````"8`````0````(`
M````````F)I```````"8F@````````0````````````````````$````````
M````````````H@````X````#`````````,"=00``````P)T````````(````
M````````````````"````````````````````*X````/`````P````````#(
MG4$``````,B=````````"`````````````````````@`````````````````
M``"Z`````0````,`````````T)U!``````#0G0````````@`````````````
M```````(````````````````````OP````8````#`````````-B=00``````
MV)T``````````@````````8`````````"``````````0`````````,@````!
M`````P````````#8GT$``````-B?````````$`````````````````````@`
M````````"`````````#-`````0````,`````````Z)]!``````#HGP``````
M`$`"```````````````````(``````````@`````````U@````$````#````
M`````"BB00``````**(````````@````````````````````"```````````
M`````````-P````(`````P````````!(HD$``````$BB````````:!``````
M``````````````@```````````````````#A`````0```#``````````````
M``````!(H@```````%8````````````````````!``````````$`````````
M`0````,`````````````````````````GJ(```````#J````````````````
3`````0``````````````````````
